@@ -14,11 +14,11 @@ App::Prove::State::Result - Individual test suite results.
 
 =head1 VERSION
 
-Version 3.24
+Version 3.27
 
 =cut
 
-$VERSION = '3.24';
+$VERSION = '3.27';
 
 =head1 DESCRIPTION
 
@@ -29,7 +29,7 @@ single test suite run.
 =head1 SYNOPSIS
 
     # Re-run failed tests
-    $ prove --state=fail,save -rbv
+    $ prove --state=failed,save -rbv
 
 =cut
 
