@@ -10,11 +10,11 @@ TAP::Parser::Scheduler::Spinner - A no-op job.
 
 =head1 VERSION
 
-Version 3.24
+Version 3.27
 
 =cut
 
-$VERSION = '3.24';
+$VERSION = '3.27';
 
 =head1 SYNOPSIS
 
@@ -34,12 +34,14 @@ return a real job.
 
     my $job = TAP::Parser::Scheduler::Spinner->new;
 
-Returns a new C<TAP::Parser::Scheduler::Spinner> object.
+Ignores any arguments and returns a new C<TAP::Parser::Scheduler::Spinner> object.
 
 =cut
 
 sub new { bless {}, shift }
 
+=head2 Instance Methods
+
 =head3 C<is_spinner>
 
 Returns true indicating that is a 'spinner' job. Spinners are returned
@@ -50,4 +52,10 @@ return one right now.
 
 sub is_spinner {1}
 
+=head1 SEE ALSO
+
+L<TAP::Parser::Scheduler>, L<TAP::Parser::Scheduler::Job>
+
+=cut
+
 1;
